@@ -11,13 +11,11 @@ from tqdm import tqdm
 from quark import config
 from quark.Objects.quark import Quark
 from quark.Objects.quarkrule import QuarkRule
-from quark.freshquark import check_update
 from quark.logo import logo
 from quark.utils.out import print_success, print_info, print_warning
 from quark.utils.weight import Weight
 
 logo()
-check_update()
 
 
 @click.command(no_args_is_help=True)
@@ -70,12 +68,28 @@ check_update()
 @click.option(
     "-i",
     "--list",
-    is_flag=True,
     help="List classes, methods and descriptors",
+    type=click.Choice(["all", "native", "custom"]),
+    required=False,
+)
+@click.option(
+    "-p",
+    "--permission",
+    help="List Android permissions",
+    is_flag=True,
     required=False,
 )
 def entry_point(
-    summary, detail, apk, rule, output, graph, classification, threshold, list
+    summary,
+    detail,
+    apk,
+    rule,
+    output,
+    graph,
+    classification,
+    threshold,
+    list,
+    permission,
 ):
     """Quark is an Obfuscation-Neglect Android Malware Scoring System"""
 
@@ -146,8 +160,20 @@ def entry_point(
 
     if list:
 
-        for api in data.apkinfo.android_apis:
-            print(api.full_name)
+        if list == "all":
+            for all_method in data.apkinfo.all_methods:
+                print(all_method.full_name)
+        if list == "native":
+            for api in data.apkinfo.android_apis:
+                print(api.full_name)
+        if list == "custom":
+            for custom_method in data.apkinfo.custom_methods:
+                print(custom_method.full_name)
+
+    if permission:
+
+        for p in data.apkinfo.permissions:
+            print(p)
 
 
 if __name__ == "__main__":
